==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/admin/messages/pt-BR/settings.php <==
<?php

return [
    '1 month' => '1 mês',
    '1 week' => '1 semana',
    '1 year' => '1 ano',
    '2 weeks' => '2 semanas',
    '3 months' => '3 meses',
    '6 months' => '6 meses',
    '<strong>Confirm</strong> icon deletion' => '<strong> Confirmar</strong>exclusão do ícone',
    '<strong>Confirm</strong> image deletion' => '<strong>Confirmar</strong> exclusão de imagem',
    '<strong>Maintenance</strong> Mode' => '<strong>Modo</strong> Manutenção',
    '<strong>Warning:</strong> All users will be immediately logged out, except admins.' => '<strong>Aviso::</strong> Todos os usuários serão desconectados imediatamente, exceto os administradores.',
    'APC(u)' => 'APC(u)',
    'Activate' => 'Ativar',
    'Activate maintenance mode and disable access to the platform for non-admin users?<br><br>' => 'Ativar o modo de manutenção e desativar o acesso à plataforma para usuários que não são administradores? <br><br>',
    'Add OEmbed provider' => 'Adicionar provedor OEmbed',
    'Add custom info text for maintenance mode. Displayed on the login page.' => 'Adicione texto informativo personalizado para o modo de manutenção. Exibido na página de Conecte-se.',
    'Add new provider' => 'Adicionar novo provedor',
    'Advanced Settings' => 'Configurações Avançadas',
    'Allow Self-Signed Certificates?' => 'Permitir certificados auto assinados?',
    'Allowed file extensions' => 'Permitir extensões de arquivo',
    'Alphabetical' => 'Alfabética',
    'Appearance Settings' => 'Configurações de Aparência',
    'Auto format based on user language - Example: {example}' => 'Auto formato baseado na linguagem do usuário - Exemplo: {example}',
    'Back to overview' => 'Voltar para a visão geral',
    'Base URL' => 'URL base',
    'Cache Backend' => 'Backend de cache',
    'Comma separated list. Leave empty to allow all.' => 'Lista separada por vírgulas. Deixe em branco para permitir todos.',
    'Could not send test email.' => 'Não foi possível enviar o email de teste.',
    'Currently no provider active!' => 'Atualmente nenhum provedor está ativo!',
    'Currently there are {count} records in the database dating from {dating}.' => 'Temos atualmente {count} registros no banco de dados desde {dating}.',
    'Dashboard' => 'Painel',
    'Date input format' => 'Formato de data',
    'Deactivate' => 'Desativar',
    'Deactivate maintenance mode and enable all users to access the platform again?' => 'Desativar modo de manutenção e permitir que todos os usuários acessem a plataforma novamente?',
    'Default Expire Time (in seconds)' => 'Tempo padrão para expirar (em segundos)',
    'Default language' => 'Idioma padrão',
    'Default pagination size (Entries per page)' => 'Tamanho padrão da paginação (Resultados por página)',
    'Default stream content order' => 'Ordem padrão do stream',
    'Delete' => 'Excluir',
    'Display Name (Format)' => 'Exibir Nome (Formato)',
    'Dropdown space order' => 'Ordem da lista de espaços',
    'E-Mail' => 'E-mail',
    'E-Mail sender address' => 'Email que irá enviar',
    'E-Mail sender name' => 'Nome que irá enviar',
    'E.g. http://example.com/humhub' => 'Exemplo: http://exemplo.com.br/humhub',
    'Edit OEmbed provider' => 'Editar provedor OEmbed',
    'Enable maintenance mode' => 'Ativar modo de manutenção',
    'Enable user friendship system' => 'Habilitar interface simplificada para o usuário.',
    'Enabled' => 'Habilitado',
    'Enabled OEmbed providers' => 'Ativar provedores OEmbed',
    'Encryption' => 'Encriptação',
    'Endpoint Url' => 'Final da URL',
    'Exclude media files from stream attachment list' => 'Excluir arquivos de mídia da lista de anexos de fluxo',
    'File' => 'Arquivo',
    'Firstname Lastname (e.g. John Doe)' => 'Primeiro e último nome (p. ex. João Silva)',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => 'Formato fixo (dd / mm / aaaa) - Exemplo: {example}',
    'Friendship' => 'Amizades',
    'General' => 'Geral',
    'General Settings' => 'Configurações Gerais',
    'HTML tracking code' => 'Código de rastreamento HTML',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Aqui você pode configurar o comportamento de registro e configurações adicionais de usuário de sua rede social.',
    'Here you can configure basic settings of your social network.' => 'Aqui você pode configurar as definições básicas de sua rede social.',
    'Horizontal scrolling images on a mobile device' => 'Imagens de rolagem horizontal em um dispositivo móvel',
    'Icon upload' => 'Upload de ícone',
    'Last visit' => 'Última visita',
    'Logo upload' => 'Enviar logomarca',
    'Mail Transport Type' => 'Tipo de Transporte de Email',
    'Maintenance mode' => 'Modo de manutenção',
    'Maximum allowed age for logs.' => 'Idade máxima permitida para logs.',
    'Maximum upload file size (in MB)' => 'Tamanho máximo de arquivo (em MB)',
    'Mobile appearance' => 'Aparência móvel',
    'Name of the application' => 'Nome da aplicação',
    'No Proxy Hosts' => 'Nenhum servidor proxy',
    'No caching' => 'Sem cache',
    'Notification Settings' => 'Configurações de Notificação',
    'Old logs can significantly increase the size of your database while providing little information.' => 'Logs antigos podem aumentar significantemente o tamanho de sua base de dados enquanto providencia pouca informação.',
    'PHP APC(u) Extension missing - Type not available!' => 'Extensão PHP APC(u) faltando - Tipo indisponível!',
    'PHP reported a maximum of {maxUploadSize} MB' => 'O PHP permite um máximo de {maxUploadSize} MB',
    'Password' => 'Senha',
    'Port' => 'Porta',
    'Port number' => 'Número da porta',
    'Prevent client caching of following scripts' => 'Impedir o cache do cliente dos seguintes scripts',
    'Redis' => 'Redis',
    'Reported database time: {dateTime}' => 'Tempo de banco de dados relatado: {dateTime}',
    'SMTP Options' => 'Opções de SMTP',
    'Save' => 'Salvar',
    'Save & Flush Caches' => 'Salvar &amp; Flush Caches',
    'Save & Test' => 'Salvar &amp; Testar',
    'Saved' => 'Salvo',
    'Saved and flushed cache' => 'Salvo e cache descarregado.',
    'Saved and sent test email to: {address}' => 'Salvo e enviado e-mail de teste para: {address}',
    'Server' => 'Servidor',
    'Server Timezone' => 'Fuso horário do servidor',
    'Show introduction tour for new users' => 'Mostrar tour de introdução para novos usuários',
    'Show user profile post form on dashboard' => 'Possibilitar ao usuário postar no painel',
    'Sort by creation date' => 'Classificar por data de criação',
    'Sort by update date' => 'Classificar por data de atualização',
    'Test message' => 'Mensagem de teste',
    'Theme' => 'Tema',
    'These settings refer to advanced topics of your social network.' => 'Estas configurações referem-se a tópicos avançados de sua rede social.',
    'These settings refer to the appearance of your social network.' => 'Estas configurações referem-se a aparência de sua rede social.',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'Use %url% como placeholder para URL. Formato precisa ser JSON. (por exemplo http://www.youtube.com/oembed?url=%url%&amp;format=json)',
    'Use X-Sendfile for File Downloads' => 'Usar X-Sendfile para baixar arquivos',
    'Use the default swipe to show sidebar on a mobile device' => 'Use o furto padrão para mostrar a barra lateral em um dispositivo móvel',
    'User' => 'Usuário',
    'User Settings' => 'Configurações de Usuário',
    'Username' => 'Nome de usuário',
    'Username (e.g. john)' => 'Nome de usuário (p. ex. João)',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'Você pode incluir um código HTML de Rastreamento que será adiconado à todas as páginas.',
    'You\'re using no icon at the moment. Upload your logo now.' => 'Você não está usando nenhum ícone no momento. Faça o upload do seu logotipo agora.',
    'You\'re using no logo at the moment. Upload your logo now.' => 'Você não está usando uma logomarca atualmente. Envie sua logomarca agora.',
    'never' => 'nunca',
    'Access Token' => '',
    'Access token is not provided yet.' => '',
    'Default Timezone' => '',
    'E-Mail reply-to' => '',
    'Embedded content requires the user\'s consent to be loaded' => '',
    'Optional. Default reply address for system emails like notifications.' => '',
    'Provider Name' => '',
    'Regular expression by which the link match will be checked.' => '',
    'Url Pattern' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/admin/messages/pt-BR/settings.php <==
<?php

return [
    '1 month' => '1 mês',
    '1 week' => '1 semana',
    '1 year' => '1 ano',
    '2 weeks' => '2 semanas',
    '3 months' => '3 meses',
    '6 months' => '6 meses',
    '<strong>Confirm</strong> icon deletion' => '<strong> Confirmar</strong>exclusão do ícone',
    '<strong>Confirm</strong> image deletion' => '<strong>Confirmar</strong> exclusão de imagem',
    '<strong>Maintenance</strong> Mode' => '<strong>Modo</strong> Manutenção',
    '<strong>Warning:</strong> All users will be immediately logged out, except admins.' => '<strong>Aviso:</strong> Todos os usuários serão desconectados imediatamente, exceto os administradores.',
    'Access Token' => 'Token de acesso',
    'Access token is not provided yet.' => 'Token de acesso ainda não fornecido.',
    'Activate' => 'Ativar',
    'Activate maintenance mode and disable access to the platform for non-admin users?<br><br>' => 'Ativar o modo de manutenção e desativar o acesso à plataforma para usuários que não são administradores? <br><br>',
    'Add OEmbed provider' => 'Adicionar provedor OEmbed',
    'Add custom info text for maintenance mode. Displayed on the login page.' => 'Adicione texto informativo personalizado para o modo de manutenção. Exibido na página de Conecte-se.',
    'Add new provider' => 'Adicionar novo provedor',
    'Advanced Settings' => 'Configurações Avançadas',
    'Allow Self-Signed Certificates?' => 'Permitir certificados auto assinados?',
    'Allowed file extensions' => 'Permitir extensões de arquivo',
    'Alphabetical' => 'Alfabética',
    'Appearance Settings' => 'Configurações de Aparência',
    'Auto format based on user language - Example: {example}' => 'Auto formato baseado na linguagem do usuário - Exemplo: {example}',
    'Back to overview' => 'Voltar para a visão geral',
    'Base URL' => 'URL base',
    'Comma separated list. Leave empty to allow all.' => 'Lista separada por vírgulas. Deixe em branco para permitir todos.',
    'Configuration (Use settings from configuration file)' => 'Configuração (Use as configurações do arquivo de configuração)',
    'Could not send test email.' => 'Não foi possível enviar o email de teste.',
    'Currently no provider active!' => 'Atualmente nenhum provedor está ativo!',
    'Currently there are {count} records in the database dating from {dating}.' => 'Temos atualmente {count} registros no banco de dados desde {dating}.',
    'Custom DSN' => 'DSN personalizado',
    'DSN' => 'DSN',
    'DSN Examples:' => 'Exemplos de DSN:',
    'Dashboard' => 'Painel',
    'Date input format' => 'Formato de data',
    'Deactivate' => 'Desativar',
    'Deactivate maintenance mode and enable all users to access the platform again?' => 'Desativar modo de manutenção e permitir que todos os usuários acessem a plataforma novamente?',
    'Default Timezone' => 'Fuso horário padrão',
    'Default language' => 'Idioma padrão',
    'Default pagination size (Entries per page)' => 'Tamanho padrão da paginação (Resultados por página)',
    'Default stream content order' => 'Ordem padrão do stream',
    'Delete' => 'Excluir',
    'Dropdown space order' => 'Ordem da lista de espaços',
    'E-Mail' => 'E-mail',
    'E-Mail reply-to' => 'E-mail de resposta',
    'E-Mail sender address' => 'Email que irá enviar',
    'E-Mail sender name' => 'Nome que irá enviar',
    'E.g. http://example.com/humhub' => 'Exemplo: http://exemplo.com.br/humhub',
    'Edit OEmbed provider' => 'Editar provedor OEmbed',
    'Embedded content requires the user\'s consent to be loaded' => 'O conteúdo incorporado requer o consentimento do usuário para ser carregado',
    'Enable maintenance mode' => 'Ativar modo de manutenção',
    'Enable user friendship system' => 'Habilitar interface simplificada para o usuário.',
    'Enabled' => 'Habilitado',
    'Enabled OEmbed providers' => 'Ativar provedores OEmbed',
    'Endpoint Url' => 'Final da URL',
    'Exclude media files from stream attachment list' => 'Excluir arquivos de mídia da lista de anexos de fluxo',
    'Firstname Lastname (e.g. John Doe)' => 'Primeiro e último nome (ex. João Silva)',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => 'Formato fixo (dd/mm/aaaa) - Exemplo: {example}',
    'Friendship' => 'Amizades',
    'General' => 'Geral',
    'General Settings' => 'Configurações Gerais',
    'HTML tracking code' => 'Código de rastreamento HTML',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Aqui você pode configurar o comportamento de registro e configurações adicionais de usuário de sua rede social.',
    'Here you can configure basic settings of your social network.' => 'Aqui você pode configurar as definições básicas de sua rede social.',
    'Horizontal scrolling images on a mobile device' => 'Imagens de rolagem horizontal em um dispositivo móvel',
    'Icon upload' => 'Upload de ícone',
    'Last visit' => 'Última visita',
    'Logo upload' => 'Enviar logomarca',
    'Mail Transport Type' => 'Tipo de Transporte de Email',
    'Maintenance mode' => 'Modo de manutenção',
    'Maximum allowed age for logs.' => 'Idade máxima permitida para logs.',
    'Maximum upload file size (in MB)' => 'Tamanho máximo de arquivo (em MB)',
    'Mobile appearance' => 'Aparência móvel',
    'Name of the application' => 'Nome da aplicação',
    'No Delivery (Debug Mode, Save as file)' => 'Sem Entrega (Modo Debug, Salvar como arquivo)',
    'No Proxy Hosts' => 'Nenhum servidor proxy',
    'Notification Settings' => 'Configurações de Notificação',
    'Old logs can significantly increase the size of your database while providing little information.' => 'Logs antigos podem aumentar significantemente o tamanho de sua base de dados enquanto providencia pouca informação.',
    'Optional. Default reply address for system emails like notifications.' => 'Opcional. Endereço de resposta padrão para e-mails do sistema como notificações.',
    'PHP (Use settings of php.ini file)' => 'PHP (Use as configurações do arquivo php.ini)',
    'PHP reported a maximum of {maxUploadSize} MB' => 'O PHP permite um máximo de {maxUploadSize} MB',
    'Password' => 'Senha',
    'Port' => 'Porta',
    'Port number' => 'Número da porta',
    'Provider Name' => 'Nome do provedor',
    'Regular expression by which the link match will be checked.' => 'Expressão regular pela qual a correspondência do link será verificada.',
    'Reported database time: {dateTime}' => 'Tempo de banco de dados relatado: {dateTime}',
    'Save' => 'Salvar',
    'Save & Flush Caches' => 'Salvar &amp; Flush Caches',
    'Save & Test' => 'Salvar &amp; Testar',
    'Saved' => 'Salvo',
    'Saved and flushed cache' => 'Salvo e cache descarregado.',
    'Saved and sent test email to: {address}' => 'Salvo e enviado e-mail de teste para: {address}',
    'Server' => 'Servidor',
    'Server Timezone' => 'Fuso horário do servidor',
    'Show introduction tour for new users' => 'Mostrar tour de introdução para novos usuários',
    'Show user profile post form on dashboard' => 'Possibilitar ao usuário postar no painel',
    'Sort by creation date' => 'Classificar por data de criação',
    'Sort by update date' => 'Classificar por data de atualização',
    'Test message' => 'Mensagem de teste',
    'Theme' => 'Tema',
    'These settings refer to advanced topics of your social network.' => 'Estas configurações referem-se a tópicos avançados de sua rede social.',
    'These settings refer to the appearance of your social network.' => 'Estas configurações referem-se a aparência de sua rede social.',
    'Url Pattern' => 'Padrão de URL',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'Use %url% como placeholder para URL. Formato precisa ser JSON. (por exemplo http://www.youtube.com/oembed?url=%url%&amp;format=json)',
    'Use SMTPS' => 'Usar SMTPS',
    'Use X-Sendfile for File Downloads' => 'Usar X-Sendfile para baixar arquivos',
    'User' => 'Usuário',
    'User Display Name' => 'Nome de exibição do usuário',
    'User Display Name Subtitle' => 'Subtítulo do nome de exibição do usuário',
    'User Settings' => 'Configurações de Usuário',
    'Username' => 'Nome de usuário',
    'Username (e.g. john)' => 'Nome de usuário (p. ex. João)',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'Você pode incluir um código HTML de Rastreamento que será adiconado à todas as páginas.',
    'You can find more configuration options here:' => 'Você pode encontrar mais opções de configuração aqui:',
    'You\'re using no icon at the moment. Upload your logo now.' => 'Você não está usando nenhum ícone no momento. Faça o upload do seu logotipo agora.',
    'You\'re using no logo at the moment. Upload your logo now.' => 'Você não está usando uma logomarca atualmente. Envie sua logomarca agora.',
    'e.g. 25 (for SMTP) or 465 (for SMTPS)' => 'exemplo: 25 (para SMTP) ou 465 (para SMTPS)',
    'e.g. localhost' => 'exemplo: localhost',
    'e.g. smtps://user:pass@smtp.example.com:port' => 'exemplo: smtps://usuario:senha@smtp.exemplo.com:porta',
    'never' => 'nunca',
    'Inserted script tags must contain a nonce. e.g. {code}' => '',
];
